@@ -3,16 +3,24 @@
     SPDX-FileCopyrightText: 2014 David Edmundson <davidedmundson@kde.org>
     SPDX-FileCopyrightText: 2023 Alexander Lohnau <alexander.lohnau@gmx.de>
 
-    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include <QQmlEngine>
 #include <QQmlExtensionPlugin>
 
-#include "formats.h"
-#include "kuserproxy.h"
 #include <KAboutData>
-#include <KFormat>
+#include <KTextToHTML>
+
+class KTextToHtmlWrapper
+{
+    Q_GADGET
+    Q_INVOKABLE [[nodiscard]] static QString
+    convertToHtml(const QString &plainText, const KTextToHTML::Options &options, int maxUrlLen = 4096, int maxAddressLen = 255)
+    {
+        return KTextToHTML::convertToHtml(plainText, options, maxUrlLen, maxAddressLen);
+    }
+};
 
 class KCoreAddonsPlugin : public QQmlExtensionPlugin
 {
@@ -22,15 +30,12 @@ class KCoreAddonsPlugin : public QQmlExtensionPlugin
 public:
     void registerTypes(const char *uri) override
     {
-        qmlRegisterSingletonType<Formats>(uri, 1, 0, "Format", [](QQmlEngine *, QJSEngine *) {
-            return new Formats();
-        });
-        qRegisterMetaType<QLocale::FormatType>();
-        qmlRegisterUncreatableMetaObject(KFormat::staticMetaObject, uri, 1, 0, "FormatTypes", QString());
-        qmlRegisterType<KUserProxy>(uri, 1, 0, "KUser");
         qmlRegisterSingletonType(uri, 1, 0, "AboutData", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
             return engine->toScriptValue(KAboutData::applicationData());
         });
+        qmlRegisterSingletonType(uri, 1, 0, "KTextToHTML", [](QQmlEngine *engine, QJSEngine *) -> QJSValue {
+            return engine->toScriptValue(KTextToHtmlWrapper());
+        });
     }
 };
 
